package
module
Version:
v0.0.0-...-fd085db
Opens a new window with list of versions in this module.
Published: Oct 23, 2017
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
fsm
minimal idiomatic Go FSM (finite state machine)
Documentation
¶
Activate activates the state and it's consecutive states until the next state
is nil or encounters an error
type State interface {
Activate() (State, error)
}
State represents a state activity
StateFunc is a function that satisfies the State interface
Activate satisfies the State interface
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.